Check if data points are core points. A core point is a point with more than
min_pts points in its neighborhood.
Arguments
- data
matrix. A matrix containing, in that order,
x,yandt.x(longitude) andy(latitude) are the spatial coordinates andtis the cumulative time since a common origin (e.g.c(0, 6, 10)).- eps_spatial
Numeric. The spatial radius threshold. Points closer than this in space may belong to the same cluster.
- eps_temporal
Numeric. The temporal threshold. Points closer than this in time may belong to the same cluster.
- min_pts
Integer. Minimum number of points required to form a core point.
- ...
Additional arguments are passed on to
dbscan::frNN().
Examples
data(geolife_traj)
geolife_traj$date_time <- as.POSIXct(
paste(geolife_traj$date, geolife_traj$time),
format = "%Y-%m-%d %H:%M:%S",
tz = "GMT"
)
geolife_traj$t <- as.numeric(
geolife_traj$date_time - min(geolife_traj$date_time)
)
data <- cbind(geolife_traj$x, geolife_traj$y, geolife_traj$t)
res <- st_dbscan_corepoint(
data = data,
eps_spatial = 3,
eps_temporal = 30,
min_pts = 3
)
head(res)
#> [1] FALSE FALSE TRUE FALSE FALSE FALSE